==> apache-pulsar-3.3.9-src.tar.gz: apache-pulsar-3.3.9-src/pulsar-client-api/src/main/java/org/apache/pulsar/common/api/EncryptionContext.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.pulsar.common.api;

import java.util.Map;
import java.util.Optional;
import lombok.AllArgsConstructor;
import lombok.Getter;
import lombok.NoArgsConstructor;
import lombok.Setter;
import org.apache.pulsar.client.api.CompressionType;

/**
 * Class representing an encryption context.
 */
@Getter
@Setter
public class EncryptionContext {

    private Map<String, EncryptionKey> keys;
    private byte[] param;
    private String algorithm;
    private CompressionType compressionType;
    private int uncompressedMessageSize;
    private Optional<Integer> batchSize;

    /**
     * Encryption key with metadata.
     */
    @Getter
    @Setter
    @NoArgsConstructor
    @AllArgsConstructor
    public static class EncryptionKey {
        private byte[] keyValue;
        private Map<String, String> metadata;
    }

}

==> apache-pulsar-4.1.2-src.tar.gz: apache-pulsar-4.1.2-src/pulsar-client-api/src/main/java/org/apache/pulsar/common/api/EncryptionContext.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.pulsar.common.api;

import java.util.Map;
import java.util.Optional;
import lombok.AllArgsConstructor;
import lombok.Getter;
import lombok.NoArgsConstructor;
import lombok.Setter;
import org.apache.pulsar.client.api.CompressionType;

/**
 * Class representing an encryption context.
 */
@Getter
@Setter
public class EncryptionContext {

    private Map<String, EncryptionKey> keys;
    private byte[] param;
    private String algorithm;
    private CompressionType compressionType;
    private int uncompressedMessageSize;
    private Optional<Integer> batchSize;
    // Indicates whether the message payload remains encrypted (true) or has been successfully decrypted (false)
    private boolean isEncrypted;

    /**
     * Encryption key with metadata.
     */
    @Getter
    @Setter
    @NoArgsConstructor
    @AllArgsConstructor
    public static class EncryptionKey {
        private byte[] keyValue;
        private Map<String, String> metadata;
    }

}
